@@ -4,6 +4,7 @@ import csv
 import hashlib
 import os
 import stat
+import sys
 import tempfile
 import zipfile
 from io import StringIO
@@ -46,7 +47,7 @@ class RecordFile:
     def construct(self) -> str:
         return self.__file_obj.getvalue()
 
-    def __enter__(self) -> RecordFile:
+    def __enter__(self) -> RecordFile:  # noqa: PYI034
         return self
 
     def __exit__(
@@ -139,7 +140,7 @@ class WheelArchive:
 
         return relative_path, f'sha256={hash_digest}', str(len(contents))
 
-    def __enter__(self) -> WheelArchive:
+    def __enter__(self) -> WheelArchive:  # noqa: PYI034
         return self
 
     def __exit__(
@@ -167,6 +168,7 @@ class WheelBuilderConfig(BuilderConfig):
         self.__shared_data: dict[str, str] | None = None
         self.__extra_metadata: dict[str, str] | None = None
         self.__strict_naming: bool | None = None
+        self.__macos_max_compat: bool | None = None
 
     def set_default_file_selection(self) -> None:
         if self.__include or self.__exclude or self.__packages or self.__only_include:
@@ -177,26 +179,34 @@ class WheelBuilderConfig(BuilderConfig):
             self.builder.normalize_file_name_component(self.builder.metadata.core.name),
         ):
             if os.path.isfile(os.path.join(self.root, project_name, '__init__.py')):
-                self.__packages.append(project_name)
+                normalized_project_name = self.get_raw_fs_path_name(self.root, project_name)
+                self.__packages.append(normalized_project_name)
                 break
-            elif os.path.isfile(os.path.join(self.root, 'src', project_name, '__init__.py')):
-                self.__packages.append(f'src/{project_name}')
-                break
-            elif os.path.isfile(os.path.join(self.root, f'{project_name}.py')):
-                self.__only_include.append(f'{project_name}.py')
-                break
-            else:
-                from glob import glob
 
-                possible_namespace_packages = glob(os.path.join(self.root, '*', project_name, '__init__.py'))
-                if len(possible_namespace_packages) == 1:
-                    relative_path = os.path.relpath(possible_namespace_packages[0], self.root)
-                    namespace = relative_path.split(os.sep)[0]
-                    self.__packages.append(namespace)
-                    break
+            if os.path.isfile(os.path.join(self.root, 'src', project_name, '__init__.py')):
+                normalized_project_name = self.get_raw_fs_path_name(os.path.join(self.root, 'src'), project_name)
+                self.__packages.append(f'src/{normalized_project_name}')
+                break
+
+            module_file = f'{project_name}.py'
+            if os.path.isfile(os.path.join(self.root, module_file)):
+                normalized_project_name = self.get_raw_fs_path_name(self.root, module_file)
+                self.__only_include.append(module_file)
+                break
+
+            from glob import glob
+
+            possible_namespace_packages = glob(os.path.join(self.root, '*', project_name, '__init__.py'))
+            if len(possible_namespace_packages) == 1:
+                relative_path = os.path.relpath(possible_namespace_packages[0], self.root)
+                namespace = relative_path.split(os.sep)[0]
+                self.__packages.append(namespace)
+                break
         else:
-            self.__include.append('*.py')
-            self.__exclude.append('test*')
+            message = (
+                'At least one file selection option must be defined, see: https://hatch.pypa.io/latest/config/build/'
+            )
+            raise ValueError(message)
 
     def default_include(self) -> list[str]:
         if not self.__include_defined:
@@ -258,13 +268,15 @@ class WheelBuilderConfig(BuilderConfig):
                         f'cannot be an empty string'
                     )
                     raise ValueError(message)
-                elif not isinstance(relative_path, str):
+
+                if not isinstance(relative_path, str):
                     message = (
                         f'Path for source `{source}` in field '
                         f'`tool.hatch.build.targets.{self.plugin_name}.shared-data` must be a string'
                     )
                     raise TypeError(message)
-                elif not relative_path:
+
+                if not relative_path:
                     message = (
                         f'Path for source `{source}` in field '
                         f'`tool.hatch.build.targets.{self.plugin_name}.shared-data` cannot be an empty string'
@@ -290,13 +302,15 @@ class WheelBuilderConfig(BuilderConfig):
                         f'cannot be an empty string'
                     )
                     raise ValueError(message)
-                elif not isinstance(relative_path, str):
+
+                if not isinstance(relative_path, str):
                     message = (
                         f'Path for source `{source}` in field '
                         f'`tool.hatch.build.targets.{self.plugin_name}.extra-metadata` must be a string'
                     )
                     raise TypeError(message)
-                elif not relative_path:
+
+                if not relative_path:
                     message = (
                         f'Path for source `{source}` in field '
                         f'`tool.hatch.build.targets.{self.plugin_name}.extra-metadata` cannot be an empty string'
@@ -325,6 +339,36 @@ class WheelBuilderConfig(BuilderConfig):
 
         return self.__strict_naming
 
+    @property
+    def macos_max_compat(self) -> bool:
+        if self.__macos_max_compat is None:
+            macos_max_compat = self.target_config.get('macos-max-compat', True)
+            if not isinstance(macos_max_compat, bool):
+                message = f'Field `tool.hatch.build.targets.{self.plugin_name}.macos-max-compat` must be a boolean'
+                raise TypeError(message)
+
+            self.__macos_max_compat = macos_max_compat
+
+        return self.__macos_max_compat
+
+    if sys.platform in {'darwin', 'win32'}:
+
+        @staticmethod
+        def get_raw_fs_path_name(directory: str, name: str) -> str:
+            normalized = name.casefold()
+            entries = os.listdir(directory)
+            for entry in entries:
+                if entry.casefold() == normalized:
+                    return entry
+
+            return name  # no cov
+
+    else:
+
+        @staticmethod
+        def get_raw_fs_path_name(directory: str, name: str) -> str:  # noqa: ARG004
+            return name
+
 
 class WheelBuilder(BuilderInterface):
     """
@@ -336,10 +380,14 @@ class WheelBuilder(BuilderInterface):
     def get_version_api(self) -> dict[str, Callable]:
         return {'standard': self.build_standard, 'editable': self.build_editable}
 
-    def get_default_versions(self) -> list[str]:
+    def get_default_versions(self) -> list[str]:  # noqa: PLR6301
         return ['standard']
 
-    def clean(self, directory: str, versions: list[str]) -> None:
+    def clean(  # noqa: PLR6301
+        self,
+        directory: str,
+        versions: list[str],  # noqa: ARG002
+    ) -> None:
         for filename in os.listdir(directory):
             if filename.endswith('.whl'):
                 os.remove(os.path.join(directory, filename))
@@ -371,8 +419,8 @@ class WheelBuilder(BuilderInterface):
     def build_editable(self, directory: str, **build_data: Any) -> str:
         if self.config.dev_mode_dirs:
             return self.build_editable_explicit(directory, **build_data)
-        else:
-            return self.build_editable_detection(directory, **build_data)
+
+        return self.build_editable_detection(directory, **build_data)
 
     def build_editable_detection(self, directory: str, **build_data: Any) -> str:
         from editables import EditableProject
@@ -383,7 +431,7 @@ class WheelBuilder(BuilderInterface):
             self.artifact_project_id, reproducible=self.config.reproducible
         ) as archive, RecordFile() as records:
             exposed_packages = {}
-            for included_file in self.recurse_project_files():
+            for included_file in self.recurse_selected_project_files():
                 if not included_file.path.endswith('.py'):
                     continue
 
@@ -424,7 +472,11 @@ class WheelBuilder(BuilderInterface):
                 for relative_path in exposed_packages.values():
                     editable_project.add_to_path(os.path.dirname(relative_path))
 
-            for filename, content in sorted(editable_project.files()):
+            for raw_filename, content in sorted(editable_project.files()):
+                filename = raw_filename
+                if filename.endswith('.pth') and not filename.startswith('_'):
+                    filename = f'_{filename}'
+
                 record = archive.write_file(filename, content)
                 records.write(record)
 
@@ -433,7 +485,8 @@ class WheelBuilder(BuilderInterface):
                 records.write(record)
 
             extra_dependencies = list(build_data['dependencies'])
-            for dependency in editable_project.dependencies():
+            for raw_dependency in editable_project.dependencies():
+                dependency = raw_dependency
                 if dependency == 'editables':
                     dependency += f'~={EDITABLES_MINIMUM_VERSION}'
                 else:  # no cov
@@ -462,7 +515,7 @@ class WheelBuilder(BuilderInterface):
                 for relative_directory in self.config.dev_mode_dirs
             )
 
-            record = archive.write_file(f"{self.metadata.core.name.replace('-', '_')}.pth", '\n'.join(directories))
+            record = archive.write_file(f"_{self.metadata.core.name.replace('-', '_')}.pth", '\n'.join(directories))
             records.write(record)
 
             for included_file in self.recurse_forced_files(self.get_forced_inclusion_map(build_data)):
@@ -517,7 +570,8 @@ class WheelBuilder(BuilderInterface):
         # extra_metadata/ - write last
         self.add_extra_metadata(archive, records, build_data)
 
-    def write_archive_metadata(self, archive: WheelArchive, records: RecordFile, build_data: dict[str, Any]) -> None:
+    @staticmethod
+    def write_archive_metadata(archive: WheelArchive, records: RecordFile, build_data: dict[str, Any]) -> None:
         from packaging.tags import parse_tag
 
         metadata = f"""\
@@ -602,20 +656,31 @@ Root-Is-Purelib: {'true' if build_data['pure_python'] else 'false'}
         tag_parts = [tag.interpreter, tag.abi, tag.platform]
 
         archflags = os.environ.get('ARCHFLAGS', '')
-        if sys.platform == 'darwin' and archflags and sys.version_info[:2] >= (3, 8):
-            import platform
-            import re
+        if sys.platform == 'darwin':
+            if archflags and sys.version_info[:2] >= (3, 8):
+                import platform
+                import re
+
+                archs = re.findall(r'-arch (\S+)', archflags)
+                if archs:
+                    plat = tag_parts[2]
+                    current_arch = platform.mac_ver()[2]
+                    new_arch = 'universal2' if set(archs) == {'x86_64', 'arm64'} else archs[0]
+                    tag_parts[2] = f'{plat[:plat.rfind(current_arch)]}{new_arch}'
+
+            if self.config.macos_max_compat:
+                import re
 
-            archs = re.findall(r'-arch (\S+)', archflags)
-            if archs:
                 plat = tag_parts[2]
-                current_arch = platform.mac_ver()[2]
-                new_arch = 'universal2' if set(archs) == {'x86_64', 'arm64'} else archs[0]
-                tag_parts[2] = f'{plat[:plat.rfind(current_arch)]}{new_arch}'
+                sdk_match = re.search(r'macosx_(\d+_\d+)', plat)
+                if sdk_match:
+                    sdk_version_part = sdk_match.group(1)
+                    if tuple(map(int, sdk_version_part.split('_'))) >= (11, 0):
+                        tag_parts[2] = plat.replace(sdk_version_part, '10_16', 1)
 
         return '-'.join(tag_parts)
 
-    def get_default_build_data(self) -> dict[str, Any]:
+    def get_default_build_data(self) -> dict[str, Any]:  # noqa: PLR6301
         return {
             'infer_tag': False,
             'pure_python': True,
