@@ -1,14 +1,21 @@
+from __future__ import annotations
+
 import argparse
+from typing import Any
 
 
-def version_impl(called_by_app, desired_version):
+def version_impl(
+    *,
+    called_by_app: bool,  # noqa: ARG001
+    desired_version: str,
+) -> None:
     import os
 
-    from hatchling.bridge.app import get_application
+    from hatchling.bridge.app import Application
     from hatchling.metadata.core import ProjectMetadata
     from hatchling.plugin.manager import PluginManager
 
-    app = get_application(called_by_app)
+    app = Application()
 
     root = os.getcwd()
     plugin_manager = PluginManager()
@@ -18,7 +25,7 @@ def version_impl(called_by_app, desired_version):
         if desired_version:
             app.abort('Cannot set version when it is statically defined by the `project.version` field')
         else:
-            app.display_always(app.project.metadata.core.version)
+            app.display(metadata.core.version)
             return
 
     source = metadata.hatch.version.source
@@ -27,7 +34,7 @@ def version_impl(called_by_app, desired_version):
     original_version = version_data['version']
 
     if not desired_version:
-        app.display_always(original_version)
+        app.display(original_version)
         return
 
     updated_version = metadata.hatch.version.scheme.update(desired_version, original_version, version_data)
@@ -37,7 +44,7 @@ def version_impl(called_by_app, desired_version):
     app.display_info(f'New: {updated_version}')
 
 
-def version_command(subparsers, defaults):
+def version_command(subparsers: argparse._SubParsersAction, defaults: Any) -> None:  # noqa: SLF001
     parser = subparsers.add_parser('version')
     parser.add_argument('desired_version', default='', nargs='?', **defaults)
     parser.add_argument('--app', dest='called_by_app', action='store_true', help=argparse.SUPPRESS)
